Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }
Compiles JMESPath expressions.

Most use cases don’t need to worry about how Runtime works. You really only need to create your own Runtimes if you are utilizing custom functions in your expressions.

Implementations

Source

impl Runtime

pub fn new() -> Runtime

Creates a new Runtime.

pub fn compile<'a>( &'a self, expression: &str, ) -> Result<Expression<'a>, JmespathError>

Creates a new JMESPath expression from an expression string.

The provided expression is expected to adhere to the JMESPath grammar: http://jmespath.org/specification.html

pub fn register_function(&mut self, name: &str, f: Box<dyn Function>)

Adds a new function to the runtime.

pub fn deregister_function(&mut self, name: &str) -> Option<Box<dyn Function>>

Removes a function from the runtime.

Returns the function that was removed if it was found.

pub fn get_function<'a>(&'a self, name: &str) -> Option<&'a dyn Function>

Gets a function by name from the runtime.

pub fn register_builtin_functions(&mut self)

Registers all of the builtin JMESPath functions with the runtime.